#![no_std]
#![no_main]
#![deny(
    clippy::mem_forget,
    reason = "mem::forget is generally not safe to do with esp_hal types, especially those \
    holding buffers for the duration of a data transfer."
)]

use embassy_executor::Spawner;
use embassy_time::{Duration, Timer};
use esp_backtrace as _;
use esp_hal::{clock::CpuClock, timer::systimer::SystemTimer};
use esp_println::println;
use panic_abort as _;

//extern crate alloc;

esp_bootloader_esp_idf::esp_app_desc!();

#[esp_hal_embassy::main]
async fn main(_spawner: Spawner) {
    println!("Embassy starting!");

    let config: esp_hal::Config = esp_hal::Config::default()
    .with_cpu_clock(CpuClock::_240MHz);
    let peripherals: esp_hal::peripherals::Peripherals = esp_hal::init(config);

    let timer0: SystemTimer<'_> = SystemTimer::new(peripherals.SYSTIMER);
    esp_hal_embassy::init(timer0.alarm0);

    println!("Embassy initialized!");

    loop {
        println!("Hello world!");
        Timer::after(Duration::from_millis(500)).await;
    }
}
